@@ -29,10 +29,11 @@
 #endif
 
 #include <stdlib.h>
+#include <stdbool.h>
 
-#include <bluetooth/bluetooth.h>
-#include <bluetooth/sdp.h>
-#include <bluetooth/sdp_lib.h>
+#include "lib/bluetooth.h"
+#include "lib/sdp.h"
+#include "lib/sdp_lib.h"
 
 #include "sdpd.h"
 #include "log.h"
